==> open-xchange-blackwhitelist_7.6.1.orig.tar.bz2: open-xchange-blackwhitelist-7.6.1/com.openexchange.blackwhitelist/src/com/openexchange/blackwhitelist/BlackWhiteListInterface.java <==

package com.openexchange.blackwhitelist;

import java.util.List;
import com.openexchange.exception.OXException;
import com.openexchange.tools.session.ServerSession;

/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * {@link BlackWhiteListInterface}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public interface BlackWhiteListInterface {

    /**
     * Replaces a whole list with the given entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param list The list entries.
     */
    public void setList(ServerSession session, ListType type, List<String> list) throws OXException;

    /**
     * Adds list entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param entries The entries to add.
     */
    public void addListEntries(ServerSession session, ListType type, List<String> entries) throws OXException;

    /**
     * Removes list entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param entries The entries to remove.
     */
    public void removeListEntries(ServerSession session, ListType type, List<String> entries) throws OXException;

    /**
     * Returns all entries of the given list type.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @return A List of entries.
     */
    public List<String> getList(ServerSession session, ListType type) throws OXException;
}

==> open-xchange-blackwhitelist_7.8.0.orig.tar.bz2: open-xchange-blackwhitelist-7.8.0/com.openexchange.blackwhitelist/src/com/openexchange/blackwhitelist/BlackWhiteListInterface.java <==

package com.openexchange.blackwhitelist;

import java.util.List;
import com.openexchange.exception.OXException;
import com.openexchange.tools.session.ServerSession;

/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * {@link BlackWhiteListInterface}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public interface BlackWhiteListInterface {

    /**
     * Replaces a whole list with the given entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param list The list entries.
     */
    public void setList(ServerSession session, ListType type, List<String> list) throws OXException;

    /**
     * Adds list entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param entries The entries to add.
     */
    public void addListEntries(ServerSession session, ListType type, List<String> entries) throws OXException;

    /**
     * Removes list entries.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @param entries The entries to remove.
     */
    public void removeListEntries(ServerSession session, ListType type, List<String> entries) throws OXException;

    /**
     * Returns all entries of the given list type.
     *
     * @param session The Session.
     * @param type The list type (black/white).
     * @return A List of entries.
     */
    public List<String> getList(ServerSession session, ListType type) throws OXException;
}
